from transformers import BertConfig, BertTokenizer

from ai_transformersx import *
from ai_transformersx.examples import start_example_task


class TestTransformersxTask:
    task_args: TaskArguments = parse_tasks_args()

    def test_parse_arg(self):
        assert task_args.model_args.unit_test == False

    def test_task_model(self):
        self.task_args.model_args.unit_test = True
        taskModel: TaskModel = TaskModel(self.task_args.model_args)
        assert isinstance(taskModel.config, (BertConfig))
        assert isinstance(taskModel.tokenizer, (BertTokenizer))

    def test_start_example_task(self):
        start_example_task(True,["news","-h"])



from ..transformersx_base import *
from .tasks import *
from .. import *

TASKS = dict([
    ('news', NewsSegmentTask),
    ('sentiment', SentimentTask)
])


@configclass
class TaskRunArguments:
    action: str = field('train', 'specified the action name: train,eval,predict')


@configclass
class ExampleTasksArguments():
    runArgs: TaskRunArguments = TaskRunArguments()
    taskArgs = None


def _build_arguments():
    arguments = {}
    for task_name, task_class in TASKS.items():
        arg_obj = ExampleTasksArguments()
        arg_obj.taskArgs = task_class.args_class()
        arguments[task_name] = arg_obj
    return arguments


def start_example_task(test=False, args=None):
    argument_objs = _build_arguments()
    args = ["-h"] if not args else args
    task_name, arguments = ComplexArguments(argument_objs).parse(args)
    arguments.taskArgs.model_args.unit_test = test
    log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments.taskArgs)))
    task_action = arguments.runArgs.action
    task_instance = TASKS[task_name](arguments.taskArgs)

    eval('task_instance.' + task_action + '()')
